@@ -124,9 +124,8 @@ instance Read FedoraEdition where
 
 type URL = String
 
-fedoraSpins :: Release -> [FedoraEdition]
-fedoraSpins rel =
-  (if fedoraVerOrLater 42 rel then id else (KDE :)) [Budgie .. Xfce]
+fedoraSpins :: [FedoraEdition]
+fedoraSpins = [Budgie .. Xfce]
 
 fedoraVerOrLater :: Natural -> Release -> Bool
 fedoraVerOrLater _ Rawhide = True
@@ -139,8 +138,8 @@ allSpins :: Natural -> Natural -> Release -> [FedoraEdition]
 allSpins rawhide current rel =
   case rel of
     Rawhide -> allSpins rawhide current $ Fedora rawhide
-    Fedora r -> fedoraSpins rel \\ missingEditions r
-    FedoraRespin -> allSpins rawhide current (Fedora current) \\ [Cinnamon, KDEMobile, Miracle, Sway]
+    Fedora r -> fedoraSpins \\ missingEditions r
+    FedoraRespin -> allSpins rawhide current (Fedora current) \\ [KDEMobile,SoaS]
     FedoraTest -> allSpins rawhide current $ Fedora current -- FIXME use fedora-releases
     FedoraStage -> allSpins rawhide current $ Fedora (current + 1) -- FIXME use fedora-releases
     CS 9 True -> [Cinnamon, KDE, MATE, Xfce] -- FIXME missing MAX, MIN
@@ -149,15 +148,27 @@ allSpins rawhide current rel =
     CS _ _ -> []
     ELN -> []
 
+allVariants :: Natural -> Natural -> Release -> [FedoraEdition]
+allVariants rawhide current rel =
+  case rel of
+    Rawhide -> allVariants rawhide current $ Fedora rawhide
+    Fedora r -> [minBound..maxBound] \\ missingEditions r
+    FedoraRespin -> Workstation : allSpins rawhide current FedoraRespin
+    FedoraTest -> allVariants rawhide current $ Fedora current -- FIXME use fedora-releases
+    FedoraStage -> allVariants rawhide current $ Fedora (current + 1) -- FIXME use fedora-releases
+    CS _ True -> Workstation : allSpins rawhide current rel
+    CS _ False -> [Workstation]
+    _ -> error' "--all-variants not supported for this release"
+
 allEditions :: Natural -> Natural -> Release -> [FedoraEdition]
 allEditions rawhide current rel =
   case rel of
     Rawhide -> allEditions rawhide current $ Fedora rawhide
-    Fedora r -> [minBound..maxBound] \\ missingEditions r
-    FedoraRespin -> Workstation : allSpins rawhide current FedoraRespin
+    Fedora _ -> [Workstation, KDE, Server, Cloud, IoT]
+    FedoraRespin -> [Workstation, KDE]
     FedoraTest -> allEditions rawhide current $ Fedora current -- FIXME use fedora-releases
     FedoraStage -> allEditions rawhide current $ Fedora (current + 1) -- FIXME use fedora-releases
-    CS _ True -> Workstation : allSpins rawhide current rel
+    CS _ True -> [Workstation, KDE]
     CS _ False -> [Workstation]
     _ -> error' "--all-editions not supported for this release"
 
@@ -168,7 +179,7 @@ missingEditions r =
           -- FIXME missing in rawhide
           -- https://dl.fedoraproject.org/pub/fedora/linux/development/43/Spins/x86_64/iso/
           -- https://dl.fedoraproject.org/pub/fedora/linux/development/rawhide/Spins/x86_64/iso/
-          if r > 43 then [I3, SoaS, Xfce] else []
+          [KDEMobile | r > 43]
     EQ -> [IoT, COSMIC_Atomic]
     LT -> [COSMIC, COSMIC_Atomic]
 
@@ -176,6 +187,7 @@ data RequestEditions = Editions Bool [FedoraEdition]
                      | AllDesktops
                      | AllSpins
                      | AllEditions
+                     | AllVariants
   deriving Eq
 
 data CheckSum = AutoCheckSum | NoCheckSum | CheckSum
@@ -288,6 +300,7 @@ main = do
     <*> (flagLongWith' AllDesktops "all-desktops" "Get all Fedora desktops" <|>
          flagLongWith' AllSpins "all-spins" "Get all Fedora Spins" <|>
          flagLongWith' AllEditions "all-editions" "Get all Fedora editions" <|>
+         flagLongWith' AllVariants "all-variants" "Get all Fedora variants" <|>
          (Editions
            <$> switchWith 'x' "exclude" "Exclude specified editions"
            <*> many (argumentWith auto "EDITION...")))
@@ -361,17 +374,18 @@ program gpg checksum debug notimeout mode dlDir dryrun run mqemu mirror dvdnet m
   successes <-
     mapM (runProgramEdition mgr mirrorUrl showdestdir gpg checksum debug mode dryrun run mqemu mirror dvdnet mchannel mcsedition arch tgtrel reqeditions) $
     if mode == List
-    then [Workstation]
+    then [Workstation] -- single dummy value
     else
       case reqeditions of
-        AllDesktops -> Workstation : allSpins rawhide current tgtrel
+        AllDesktops -> Workstation : KDE : allSpins rawhide current tgtrel
         AllEditions -> allEditions rawhide current tgtrel
+        AllVariants -> allVariants rawhide current tgtrel
         AllSpins -> allSpins rawhide current tgtrel
         Editions False editions ->
           if null editions then [Workstation] else editions
         Editions True [] -> error' "cannot exclude zero editions"
         Editions True editions ->
-           allEditions rawhide current tgtrel \\ editions
+           allVariants rawhide current tgtrel \\ editions
   let failures = length $ filter not successes
   when (failures > 0) $ error' $ plural failures "download" +-+ "failed"
 
@@ -444,9 +458,10 @@ runProgramEdition mgr mirrorUrl showdestdir gpg checksum debug mode dryrun run m
       current <- getCurrentFedoraVersion
       let editions =
             case reqeditions of
-              AllDesktops -> Workstation : allSpins rawhide current tgtrel
+              AllDesktops -> Workstation : KDE : allSpins rawhide current tgtrel
+              AllEditions -> allEditions rawhide current tgtrel
               AllSpins -> allSpins rawhide current tgtrel
-              _ -> allEditions rawhide current tgtrel
+              _ -> allVariants rawhide current tgtrel
           extras =
             case tgtrel of
               CS _ True -> ["max","min"]
@@ -611,7 +626,7 @@ runProgramEdition mgr mirrorUrl showdestdir gpg checksum debug mode dryrun run m
     urlPathMRel :: IO (FilePath, Maybe String)
     urlPathMRel = do
       let subdir =
-            if edition `elem` fedoraSpins tgtrel
+            if edition `elem` fedoraSpins
             then joinPath ["Spins", showArch arch, "iso"]
             else joinPath [showShortEdition tgtrel edition, showArch arch, editionMedia edition]
       case tgtrel of
@@ -723,6 +738,9 @@ runProgramEdition mgr mirrorUrl showdestdir gpg checksum debug mode dryrun run m
     -- https://pagure.io/pungi-fedora/blob/main/f/fedora.conf#_251 kiwibuild
     kiwiSpins :: [FedoraEdition]
     kiwiSpins =
+      (if fedoraVerOrLater 44 tgtrel
+       then [Cinnamon, LXDE, MATE, Sway]
+       else []) ++
       [I3 | fedoraVerOrLater 43 tgtrel] ++
       -- https://fedoraproject.org/wiki/Changes/EROFSforLiveMedia
       (if fedoraVerOrLater 42 tgtrel
@@ -917,9 +935,9 @@ liveRespin :: FedoraEdition -> String
 liveRespin Budgie = "Budgie"
 liveRespin COSMIC = "COSMIC"
 liveRespin I3 = "i3"
-liveRespin LXQt = "LXQt"
+-- liveRespin LXQt = "LXQt"
 liveRespin Miracle = "MiracleWM"
-liveRespin Sway = "Sway"
+-- liveRespin Sway = "Sway"
 liveRespin e = take 4 . upper . showEdition FedoraRespin $ e
 
 bootImage :: Bool -> FilePath -> String -> Maybe String -> IO ()
