@@ -28,7 +28,7 @@ tests ghAction rawhide oldest =
     [["-c", latest, "silverblue"]
     ,["-T", "-n", latest, "everything"]
     ,["-n", previous, "server", "--dvd", "--arch", "aarch64"]
-    ,["41", "iot", "-n"]
+    ,["43", "iot", "-n"]
     ,["-n", "c8s"]
     ,["-n", "c9s", "--dvd"]
     ,["-n", "c10s"]
@@ -37,32 +37,32 @@ tests ghAction rawhide oldest =
     ,["-n", "c10s-live"]
     ]
     ++
-    allFedoraEditions oldest rawhide
+    allFedoraVariants oldest rawhide
     ++
     [["--dl", "-T", "-n", "respin", "--all-desktops"]
     ,["-T", "-n", "c9s-live", "--all-desktops"]
     ,["-T", "-n", "c10s-live", "--all-editions"]
     ]
 
-mkFedEdition :: Natural -> [String]
-mkFedEdition = mkFedEdition' . show
+mkFedVariants :: Natural -> [String]
+mkFedVariants = mkFedVariants' . show
+  where
+    mkFedVariants' :: String -> [String]
+    mkFedVariants' ver =
+      ["--dl", "-T", "-n", ver, "--all-variants"]
 
-mkFedEdition' :: String -> [String]
-mkFedEdition' ver =
-  ["--dl", "-T", "-n", ver, "--all-editions"]
-
-allFedoraEditions :: Natural -> Natural -> [[String]]
-allFedoraEditions oldest rawhide =
-  map mkFedEdition [oldest..(rawhide-1)]
+allFedoraVariants :: Natural -> Natural -> [[String]]
+allFedoraVariants oldest rawhide =
+  map mkFedVariants [oldest..(rawhide-1)]
   -- currently empty
-  -- ++ [mkFedEdition' "stage"]
+  -- ++ [mkFedVariants' "stage"]
   -- use --exclude for any missing
-  ++ [mkFedEdition rawhide]
+  ++ [mkFedVariants rawhide]
 
 allEditions :: Natural -> [String]
 allEditions 9 = allEditions 10 ++ ["cinnamon", "mate", "xfce"]
 allEditions 10 = ["workstation", "kde", "max", "min"]
-allEditions rel = ["cloud","container","everything","server","workstation","budgie","cinnamon","kde","lxde","lxqt","mate","sway","silverblue","kinoite","sericea"] ++ ["cosmic" | rel >= 42] ++ ["kdemobile" | rel >= 41] ++ ["miracle" | rel >= 41] ++ ["iot" | rel < 42] ++ ["onyx" | rel /= 43] ++ ["cosmic-atomic" | rel >= 43] ++ ["i3" | rel < 44] ++ ["soas" | rel < 44] ++ ["xfce" | rel < 44]
+allEditions rel = ["cloud","container","everything","server","workstation","budgie","cinnamon","i3", "kde","lxde","lxqt","mate","soas","sway","xfce", "silverblue","kinoite","sericea"] ++ ["cosmic" | rel >= 42] ++ ["kdemobile" | rel >= 41 && rel < 44] ++ ["miracle" | rel >= 41] ++ ["iot" | rel < 42] ++ ["onyx" | rel /= 43] ++ ["cosmic-atomic" | rel >= 43]
 
 listEditions :: Natural -> IO ()
 listEditions n = do
@@ -71,7 +71,7 @@ listEditions n = do
   es <- sort . words <$> cmd "dl-fedora" args
   let aes = sort $ allEditions n
   unless (es == aes) $
-    error' $ 'F' : show n +-+ "editions unmatched:\n" ++ show es ++ "\n" ++ show aes
+    error' $ 'F' : show n +-+ "editions unmatched:\noutput: " ++ show es ++ "\nexpect: " ++ show aes
 
 main :: IO ()
 main = do
